@@ -9,7 +9,7 @@
 #include <getopt.h>
 #include <unistd.h>
 
-#define HASH_CHECK_MODE_SET \
+#define SET_HASH_CHECK_MODE \
 {\
 	switch(optarg[0])\
 	{\
@@ -145,7 +145,7 @@ void analyze_argument(const int argc, char **argv, OPArg *oparg)
 			}
 			oparg->CHECK = V_FIVE;
 
-			HASH_CHECK_MODE_SET
+			SET_HASH_CHECK_MODE
 			break;
 
 		case 't':	/* スレッドモード */
@@ -264,7 +264,7 @@ void analyze_argument(const int argc, char **argv, OPArg *oparg)
 			{
 				int *i = xmalloc(sizeof(int));
 				*i = size;
-				b_size_list = append_list(b_size_list, i);
+				b_size_list = append_list(i, b_size_list);
 			}
 
 			if(size <= 524288)
