@@ -8,12 +8,12 @@ static VList *now;
 static VList *before_last;
 
 /* 関数プロトタイプ */
-static inline VList * append_list(VList *first, const void *tmp) __attribute__((always_inline));
+static inline VList * append_list(const void *tmp, VList *first);
 
 /*******************************************************************************
  * 連結リストに構造体を追加し、リストを繋ぐ
 *******************************************************************************/
-static inline VList * append_list(VList *first, const void *tmp)
+static inline VList * append_list(const void *tmp, VList *first)
 {
 	if(first == NULL)
 	{
