@@ -13,7 +13,7 @@
 static struct timespec time_s[2];
 
 /* 関数プロトタイプ */
-static inline void ch_time_and_mod_link(const struct stat *stat_buf, const CPInfo *cpinfo, CPDD *cpdd) __attribute__((always_inline));
+static inline void ch_time_and_mod_link(const struct stat *stat_buf, const CPInfo *cpinfo, CPDD *cpdd);
 
 /*******************************************************************************
 *******************************************************************************/
