@@ -1,10 +1,12 @@
 #define _GNU_SOURCE
 
 #include "append_list.h"	// inline
+#include "compare_verify_one.h"	// inline
 #include "create_symboliclink.h"	// inline
-#include "do_compare_verify_one.h"	// inline
 #include "print_error.h"	// inline
 #include "read_write.h"
+#include "remove_source_rmdir.h"
+#include "remove_source_unlink.h"
 #include "struct_CPDD.h"
 #include "struct_CPInfo.h"
 #include "struct_DPath.h"
@@ -26,167 +28,29 @@
 #include <utime.h>
 
 /* 関数プロトタイプ */
-RData * check_target(OPArg *, VList *, SDir *);
-void check_overwrite(const OPArg *, const SDir *, CPInfo *, CPDD *);
-struct stat * make_directory(CPInfo *, OPArg *, CPDD *);
-static VList * dir_traverse(VList *, CPInfo *, OPArg *, SDir *, CPDD *);
-static inline void delete_last_slash(const int, char []);
+RData * check_target(const OPArg *, const VList *drive_list, const SDir *);
+static inline VList * link_copy(const OPArg *, const SDir *, CPInfo *, CPDD *, VList *file_list);
+static inline VList * file_copy(const VList *drive_list, const char src[], const char dst[], const OPArg *, const SDir *, CPInfo *, CPDD *, VList *file_list);
+static inline VList * dir_copy(const char *tmp_src, const char *tmp_dst, const _Bool src_current_flag, const VList *drive_list, const OPArg *, const SDir *, CPInfo *, CPDD *, VList *file_list);
+static inline void check_overwrite(const OPArg *, const SDir *, CPInfo *, CPDD *);
+static inline void write_file_or_create_link(const OPArg *, const SDir *, CPInfo *, CPDD *);
+static inline _Bool this_dir_check(const CPInfo *cpinfo, const char *this_dir);
+static inline struct stat * make_directory(const OPArg *, CPInfo *, CPDD *);
+static VList * dir_traverse(const OPArg *, const SDir *, VList *file_list, CPInfo *, CPDD *);
+static inline void delete_last_slash(const int len, char []);
 static inline CPInfo * cpinfo_malloc(void);
-static inline char * get_dst_plus_srcname(const char *, const char *);
+static inline char * get_dst_plus_srcname(const char *src, const char *dst);
 static inline void count_link_plus(CPInfo *, CPDD *);
 static inline void count_file_plus(CPInfo *, CPDD *);
 static inline void count_dire_plus(CPInfo *, CPDD *);
 static inline void ch_time_and_mod_dir(const CPInfo *, const struct stat *, CPDD *);
-static inline void clean(const char [], const int);
+static inline void clean(const char buf[], const int len);
 static inline void fgets_is_null(void);
-static inline void set_same_or_different(const VList *, const char *, const char *, CPInfo *, OPArg *);
+static inline void set_same_or_different(const VList *drive_list, const char *src, const char *dst, const OPArg *, CPInfo *);
 
 /*******************************************************************************
 *******************************************************************************/
-#define LINK_COPY \
-{\
-	count_link_plus(cpinfo, cpdd);\
-	check_overwrite(oparg, sdir, cpinfo, cpdd);\
-	file_list = append_list(file_list, (void *)cpinfo);\
-}
-
-#define FILE_COPY \
-{\
-	count_file_plus(cpinfo, cpdd);\
-	set_same_or_different(drive_list, tmp_src, tmp_dst, cpinfo, oparg); \
-	check_overwrite(oparg, sdir, cpinfo, cpdd);\
-	file_list = append_list(file_list, (void *)cpinfo);\
-}
-
-#define DIR_COPY \
-{\
-	char *s = tmp_src;\
-	char *d = tmp_dst;\
-	_Bool parent_flag = false;\
-\
-	for(;;)\
-	{\
-		if(*s == *d)\
-		{\
-			if(*s == '\0')\
-			{\
-				parent_flag = true;\
-				break;\
-			}\
-\
-			s++;\
-			d++;\
-		}\
-		else if(*s == '\0')\
-		{\
-			parent_flag = true;\
-			break;\
-		}\
-		else if(*d == '\0')\
-		{\
-			break;\
-		}\
-		else \
-		{\
-			break;\
-		}\
-	}\
-\
-	/* cmpはstrcmpのcmp */\
-	_Bool cmp_flag = false;\
-\
-	if(src_current_flag == true)\
-	{\
-		char *s = cpinfo->src;\
-		char *d = cpinfo->dst;\
-		int s_len = strlen(s);\
-		int d_len = strlen(d);\
-\
-		if(s_len == d_len)\
-		{\
-			if(strcmp(s, d) == 0)\
-			{\
-				cmp_flag = true;\
-			}\
-		}\
-		else if(s_len < d_len)\
-		{\
-			for(;;)\
-			{\
-				if(*s == *d)\
-				{\
-					s++;\
-					d++;\
-				}\
-				else \
-				{\
-					break;\
-				}\
-\
-				if(*s == '\0')\
-				{\
-					if(*d == G_DIR_SEPARATOR)\
-					{\
-						cmp_flag = true;\
-					}\
-					break;\
-				}\
-			}\
-		}\
-	}\
-\
-	if(cmp_flag == true)\
-	{\
-		fprintf(stderr, "`.' をスキップします\n");\
-\
-		if(cpinfo->src != NULL) free(cpinfo->src);\
-		if(cpinfo->dst != NULL) free(cpinfo->dst);\
-\
-		free(cpinfo);\
-		cpinfo = NULL;\
-	}\
-	else if(parent_flag == true)\
-	{\
-		fprintf(stderr, "`%s' をスキップします\n", cpinfo->src);\
-\
-		if(cpinfo->src != NULL) free(cpinfo->src);\
-		if(cpinfo->dst != NULL) free(cpinfo->dst);\
-\
-		free(cpinfo);\
-		cpinfo = NULL;\
-	}\
-	else \
-	{\
-		set_same_or_different(drive_list, tmp_src, tmp_dst, cpinfo, oparg); \
-\
-		struct stat *stat_buf;\
-\
-		if(src_current_flag == false)\
-		{\
-			count_dire_plus(cpinfo, cpdd);\
-			stat_buf = make_directory(cpinfo, oparg, cpdd);\
-			file_list = append_list(file_list, (void *)cpinfo);\
-		}\
-		else \
-		{\
-			char *current_tmp = g_path_get_dirname(cpinfo->dst);\
-			free(cpinfo->dst);\
-			cpinfo->dst = current_tmp;\
-			/* cpinfoをリストに追加していないので、メモリリークしている。 */\
-		}\
-\
-		file_list = dir_traverse(file_list, cpinfo, oparg, sdir, cpdd);\
-\
-		if((src_current_flag == false) && (cpinfo->d_para == WRITE))\
-		{\
-			ch_time_and_mod_dir(cpinfo, stat_buf, cpdd);\
-		}\
-	}\
-}
-
-/*******************************************************************************
-*******************************************************************************/
-RData * check_target(OPArg *oparg, VList *drive_list, SDir *sdir)
+RData * check_target(const OPArg *oparg, const VList *drive_list, const SDir *sdir)
 {
 	enum argument_count
 	{
@@ -287,7 +151,22 @@ RData * check_target(OPArg *oparg, VList *drive_list, SDir *sdir)
 	}
 	else if(errno == ENOENT)
 	{
-		char *c = g_path_get_dirname(oparg->argv[loop_dst]);
+		char *d = oparg->argv[loop_dst];
+		int dlen = strlen(d);
+		char *c;
+
+		if(d[dlen - 1] == G_DIR_SEPARATOR)
+		{
+			char *z = xmalloc(dlen + 1);
+			strcpy(z, d);
+			delete_last_slash(dlen, z);
+			c = g_path_get_dirname(z);
+			oparg->argv[loop_dst] = z;
+		}
+		else
+		{
+			c = g_path_get_dirname(oparg->argv[loop_dst]);
+		}
 
 		errno = 0;
 		realpath(c, tmp_dst);
@@ -381,7 +260,7 @@ RData * check_target(OPArg *oparg, VList *drive_list, SDir *sdir)
 					}
 					else if(g_file_test(tmp_src, G_FILE_TEST_IS_REGULAR) == TRUE)
 					{
-						FILE_COPY
+						file_list = file_copy(drive_list, tmp_src, tmp_dst, oparg, sdir, cpinfo, cpdd, file_list);
 					}
 					else if(g_file_test(tmp_src, G_FILE_TEST_IS_DIR) == TRUE)
 					{
@@ -406,15 +285,15 @@ RData * check_target(OPArg *oparg, VList *drive_list, SDir *sdir)
 				cpinfo->dst = get_dst_plus_srcname(tmp_src, tmp_dst);
 				if(link_flag == true)
 				{
-					LINK_COPY
+					file_list = link_copy(oparg, sdir, cpinfo, cpdd, file_list);
 				}
 				else if(g_file_test(tmp_src, G_FILE_TEST_IS_REGULAR) == TRUE)
 				{
-					FILE_COPY
+					file_list = file_copy(drive_list, tmp_src, tmp_dst, oparg, sdir, cpinfo, cpdd, file_list);
 				}
 				else if(g_file_test(tmp_src, G_FILE_TEST_IS_DIR) == TRUE)
 				{
-					DIR_COPY
+					file_list = dir_copy(tmp_src, tmp_dst, src_current_flag, drive_list, oparg, sdir, cpinfo, cpdd, file_list);
 				}
 				else
 				{
@@ -459,15 +338,15 @@ RData * check_target(OPArg *oparg, VList *drive_list, SDir *sdir)
 
 			if(link_flag == true)
 			{
-				LINK_COPY
+				file_list = link_copy(oparg, sdir, cpinfo, cpdd, file_list);
 			}
 			else if(g_file_test(tmp_src, G_FILE_TEST_IS_REGULAR) == TRUE)
 			{
-				FILE_COPY
+				file_list = file_copy(drive_list, tmp_src, tmp_dst, oparg, sdir, cpinfo, cpdd, file_list);
 			}
 			else if(g_file_test(tmp_src, G_FILE_TEST_IS_DIR) == TRUE)
 			{
-				DIR_COPY
+				file_list = dir_copy(tmp_src, tmp_dst, src_current_flag, drive_list, oparg, sdir, cpinfo, cpdd, file_list);
 			}
 			else
 			{
@@ -489,77 +368,159 @@ RData * check_target(OPArg *oparg, VList *drive_list, SDir *sdir)
 
 /*******************************************************************************
 *******************************************************************************/
-#define DO_NOT_OVERWRITE_FLAG \
-{\
-	cpinfo->d_para = SKIP;\
+static inline VList * link_copy(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd, VList *file_list)
+{
+	count_link_plus(cpinfo, cpdd);
+	check_overwrite(oparg, sdir, cpinfo, cpdd);
+	file_list = append_list((void *)cpinfo, file_list);
+	return file_list;
 }
 
-#define FILE_WRITE_OR_CREATE_LINK_OVERWRITE \
-{\
-	if(cpinfo->src_type == REGULAR)\
-	{\
-		read_write(oparg, cpinfo, cpdd);\
-		do_compare_verify_one(oparg, sdir, cpinfo, cpdd);\
-	}\
-	else \
-	{\
-		create_symboliclink(oparg, cpinfo, cpdd);\
-	}\
+/*******************************************************************************
+*******************************************************************************/
+static inline VList * file_copy(const VList *drive_list, const char tmp_src[], const char tmp_dst[], const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd, VList *file_list)
+{
+	count_file_plus(cpinfo, cpdd);
+	set_same_or_different(drive_list, tmp_src, tmp_dst, oparg, cpinfo);
+	check_overwrite(oparg, sdir, cpinfo, cpdd);
+	file_list = append_list((void *)cpinfo, file_list);
+	return file_list;
 }
 
-#define MAKE_THIS_DIR \
-this_dir = g_path_get_dirname(cpinfo->dst);
+/*******************************************************************************
+*******************************************************************************/
+static inline VList * dir_copy(const char *tmp_src, const char *tmp_dst, const _Bool src_current_flag, const VList *drive_list, const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd, VList *file_list)
+{
+	const char *s = tmp_src;
+	const char *d = tmp_dst;
+	_Bool parent_flag = false;
 
-#define THIS_DIR_CHECK \
-{\
-	char *tmp = g_path_get_dirname(cpinfo->dst);\
-	char *tmp2 = this_dir;\
-	char *tmp_free = tmp;\
-	int tmp_len = strlen(tmp);\
-	int this_len = strlen(tmp2);\
-	_Bool flag = false;\
-\
-	if(this_len == tmp_len)\
-	{\
-		if(strcmp(tmp2, tmp) == 0)\
-		{\
-			flag = true;\
-		}\
-	}\
-	else if(this_len < tmp_len)\
-	{\
-		for(;;)\
-		{\
-			if(*tmp2 == *tmp)\
-			{\
-				tmp2++;\
-				tmp++;\
-			}\
-			else \
-			{\
-				break;\
-			}\
-\
-			if(*tmp2 == '\0')\
-			{\
-\
-				if(*tmp == G_DIR_SEPARATOR)\
-				{\
-					flag = true;\
-				}\
-				break;\
-			}\
-		}\
-	}\
-\
-	if(flag == false)\
-	{\
-		b = false;\
-	}\
-\
-	free(tmp_free);\
+	for(;;)
+	{
+		if(*s == *d)
+		{
+			if(*s == '\0')
+			{
+				parent_flag = true;
+				break;
+			}
+
+			s++;
+			d++;
+		}
+		else if(*s == '\0')
+		{
+			parent_flag = true;
+			break;
+		}
+		else if(*d == '\0')
+		{
+			break;
+		}
+		else 
+		{
+			break;
+		}
+	}
+
+	/* cmpはstrcmpのcmp */
+	_Bool cmp_flag = false;
+
+	if(src_current_flag == true)
+	{
+		char *s = cpinfo->src;
+		char *d = cpinfo->dst;
+		int s_len = strlen(s);
+		int d_len = strlen(d);
+
+		if(s_len == d_len)
+		{
+			if(strcmp(s, d) == 0)
+			{
+				cmp_flag = true;
+			}
+		}
+		else if(s_len < d_len)
+		{
+			for(;;)
+			{
+				if(*s == *d)
+				{
+					s++;
+					d++;
+				}
+				else
+				{
+					break;
+				}
+
+				if(*s == '\0')
+				{
+					if(*d == G_DIR_SEPARATOR)
+					{
+						cmp_flag = true;
+					}
+					break;
+				}
+			}
+		}
+	}
+
+	if(cmp_flag == true)
+	{
+		fprintf(stderr, "`.' をスキップします\n");
+
+		if(cpinfo->src != NULL) free(cpinfo->src);
+		if(cpinfo->dst != NULL) free(cpinfo->dst);
+
+		free(cpinfo);
+		cpinfo = NULL;
+	}
+	else if(parent_flag == true)
+	{
+		fprintf(stderr, "`%s' をスキップします\n", cpinfo->src);
+
+		if(cpinfo->src != NULL) free(cpinfo->src);
+		if(cpinfo->dst != NULL) free(cpinfo->dst);
+
+		free(cpinfo);
+		cpinfo = NULL;
+	}
+	else
+	{
+		set_same_or_different(drive_list, tmp_src, tmp_dst, oparg, cpinfo);
+
+		struct stat *stat_buf;
+
+		if(src_current_flag == false)
+		{
+			count_dire_plus(cpinfo, cpdd);
+			stat_buf = make_directory(oparg, cpinfo, cpdd);
+			file_list = append_list((void *)cpinfo, file_list);
+		}
+		else
+		{
+			char *current_tmp = g_path_get_dirname(cpinfo->dst);
+			free(cpinfo->dst);
+			cpinfo->dst = current_tmp;
+			/* cpinfoをリストに追加していないので、メモリリークしている。 */
+		}
+
+		file_list = dir_traverse(oparg, sdir, file_list, cpinfo, cpdd);
+
+		if((src_current_flag == false) && (cpinfo->dst_para == WRITE))
+		{
+			ch_time_and_mod_dir(cpinfo, stat_buf, cpdd);
+		}
+
+		if(oparg->M == MOVE) { REMOVE_SOURCE_RMDIR }
+	}
+
+	return file_list;
 }
 
+/*******************************************************************************
+*******************************************************************************/
 #define THIS_DIR_FREE \
 {\
 	if(this_dir != NULL)\
@@ -568,24 +529,26 @@ this_dir = g_path_get_dirname(cpinfo->dst);
 		this_dir = NULL;\
 	}\
 }
-
-enum I_OverWrite_Type
-{
-	INFO,
-	THIS_DIR_YES,
-	THIS_DIR_NO,
-};
-
-enum I_OverWrite_Type iowt;
-static OPFlag I;
-static OPFlag WMODE;
-static _Bool info_flag;
-static char *this_dir;
+#define DO_NOT_OVERWRITE_FLAG { cpinfo->dst_para = SKIP; }
+#define MAKE_THIS_DIR         { this_dir = g_path_get_dirname(cpinfo->dst); }
 
 /*******************************************************************************
 *******************************************************************************/
-void check_overwrite(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd)
+static inline void check_overwrite(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd)
 {
+	enum I_OverWrite_Type
+	{
+		INFO,
+		THIS_DIR_YES,
+		THIS_DIR_NO,
+	};
+
+	static enum I_OverWrite_Type iowt;
+	static _Bool info_flag;
+	static OPFlag I;
+	static OPFlag WMODE;
+	static char *this_dir;
+
 	if(info_flag == false)
 	{
 		iowt = INFO;
@@ -602,16 +565,7 @@ void check_overwrite(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD
 	/* true・false　→　stdbool */
 	if(fcheck == FALSE)
 	{
-		if(cpinfo->src_type == REGULAR)
-		{
-			read_write(oparg, cpinfo, cpdd);
-			do_compare_verify_one(oparg, sdir, cpinfo, cpdd);
-		}
-		else
-		{
-			/* create_symboliclinkでも再度、上書きチェックを行っている。 */
-			create_symboliclink(oparg, cpinfo, cpdd);
-		}
+		write_file_or_create_link(oparg, sdir, cpinfo, cpdd);
 	}
 	else
 	{
@@ -633,8 +587,9 @@ INPUT:
 			switch(iowt)
 			{
 			case INFO:
-				printf("`%s' は既に存在します。\n", cpinfo->dst);
-				puts("上書きしますか? (y: Yes  a: 全てYes  d: このフォルダのみYes  n: No  o: このフォルダのみNo  z: 全てNo)");
+				printf("overwrite ? `%s'\n", cpinfo->dst);
+				puts("y: Yes, a: Yes (All), d: Yes (Only this folder),");
+				puts("n: No,  z: No (All),  o: No (Only this folder)");
 				printf(" : ");
 
 				char stdin_buf[NAME_MAX];
@@ -661,18 +616,18 @@ INPUT:
 				switch(stdin_buf[0])
 				{
 				case 'y':	/* 上書き */
-					FILE_WRITE_OR_CREATE_LINK_OVERWRITE
+					write_file_or_create_link(oparg, sdir, cpinfo, cpdd);
 					break;
 
 				case 'a':	/* 全て上書き */
-					FILE_WRITE_OR_CREATE_LINK_OVERWRITE
+					write_file_or_create_link(oparg, sdir, cpinfo, cpdd);
 					I = NOT;	/* 上書き確認モード無効 */
 					/* WMODE = OVERWRITE; */
 					/* ↑上書き確認モードでは最初からOVERWRITEになっている */
 					break;
 
 				case 'd':	/* このフォルダでのみ上書き */
-					FILE_WRITE_OR_CREATE_LINK_OVERWRITE
+					write_file_or_create_link(oparg, sdir, cpinfo, cpdd);
 					iowt = THIS_DIR_YES;
 					THIS_DIR_FREE
 					MAKE_THIS_DIR
@@ -699,13 +654,11 @@ INPUT:
 
 			case THIS_DIR_YES:
 				{
-					_Bool b = true;
-
-					THIS_DIR_CHECK
+					_Bool b = this_dir_check(cpinfo, this_dir);
 
 					if(b == true)
 					{
-						FILE_WRITE_OR_CREATE_LINK_OVERWRITE
+						write_file_or_create_link(oparg, sdir, cpinfo, cpdd);
 					}
 					else
 					{
@@ -719,9 +672,7 @@ INPUT:
 
 			case THIS_DIR_NO:
 				{
-					_Bool b = true;
-
-					THIS_DIR_CHECK
+					_Bool b = this_dir_check(cpinfo, this_dir);
 
 					if(b == true)
 					{
@@ -746,7 +697,7 @@ INPUT:
 			}
 			else
 			{
-				FILE_WRITE_OR_CREATE_LINK_OVERWRITE
+				write_file_or_create_link(oparg, sdir, cpinfo, cpdd);
 			}
 		}
 	}
@@ -754,7 +705,91 @@ INPUT:
 
 /*******************************************************************************
 *******************************************************************************/
-struct stat * make_directory(CPInfo *cpinfo, OPArg *oparg, CPDD *cpdd)
+static inline void write_file_or_create_link(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd)
+{
+	if(cpinfo->src_type == REGULAR)
+	{
+		read_write(oparg, cpinfo, cpdd);
+
+		if(oparg->CHECK_MODE == BEFORE)
+		{
+			compare_verify_one(oparg, sdir, cpinfo, cpdd);
+		}
+
+		if((oparg->M == MOVE) && (cpinfo->dst_para == WRITE))
+		{
+			if(oparg->CHECK == NOT)
+			{
+				REMOVE_SOURCE_UNLINK
+			}
+			else if((oparg->CHECK_MODE == BEFORE) && (cpinfo->hash_check == true))
+			{
+				REMOVE_SOURCE_UNLINK
+			}
+		}
+	}
+	else
+	{
+		create_symboliclink(oparg, cpinfo, cpdd);
+
+		if((oparg->M == MOVE) && (cpinfo->dst_para == WRITE))
+		{
+			REMOVE_SOURCE_UNLINK
+		}
+	}
+}
+
+/*******************************************************************************
+*******************************************************************************/
+static inline _Bool this_dir_check(const CPInfo *cpinfo, const char *this_dir)
+{
+	char *tmp = g_path_get_dirname(cpinfo->dst);
+	char *tmp_free = tmp;
+	const char *tmp2 = this_dir;
+	int tmp_len = strlen(tmp);
+	int this_len = strlen(tmp2);
+	_Bool flag = false;
+
+	if(this_len == tmp_len)
+	{
+		if(strcmp(tmp2, tmp) == 0)
+		{
+			flag = true;
+		}
+	}
+	else if(this_len < tmp_len)
+	{
+		for(;;)
+		{
+			if(*tmp2 == *tmp)
+			{
+				tmp2++;
+				tmp++;
+			}
+			else
+			{
+				break;
+			}
+
+			if(*tmp2 == '\0')
+			{
+				if(*tmp == G_DIR_SEPARATOR)
+				{
+					flag = true;
+				}
+				break;
+			}
+		}
+	}
+
+	free(tmp_free);
+
+	return flag ? true : false;
+}
+
+/*******************************************************************************
+*******************************************************************************/
+static inline struct stat * make_directory(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
 {
 	errno = 0;
 	if(g_file_test(cpinfo->dst, G_FILE_TEST_EXISTS) == TRUE)
@@ -764,7 +799,7 @@ struct stat * make_directory(CPInfo *cpinfo, OPArg *oparg, CPDD *cpdd)
 	}
 	else if(mkdir(cpinfo->dst, 0755) == -1)
 	{
-		cpinfo->d_para = INITIAL;
+		cpinfo->dst_para = INITIAL;
 
 		if((errno != EEXIST) && (errno != 0))
 		{
@@ -780,7 +815,7 @@ struct stat * make_directory(CPInfo *cpinfo, OPArg *oparg, CPDD *cpdd)
 			fflush(stdout);
 		}
 
-		cpinfo->d_para = WRITE;
+		cpinfo->dst_para = WRITE;
 		cpdd->mk_dir_count++;
 	}
 
@@ -805,7 +840,7 @@ struct stat * make_directory(CPInfo *cpinfo, OPArg *oparg, CPDD *cpdd)
 {\
 	count_link_plus(cpinfo, cpdd);\
 	check_overwrite(oparg, sdir, cpinfo, cpdd);\
-	file_list = append_list(file_list, (void *)cpinfo);\
+	file_list = append_list((void *)cpinfo, file_list);\
 }
 
 #define TYPE_IS_FILE \
@@ -813,24 +848,25 @@ struct stat * make_directory(CPInfo *cpinfo, OPArg *oparg, CPDD *cpdd)
 	count_file_plus(cpinfo, cpdd);\
 	cpinfo->copy_mode = cpinfo_tmp->copy_mode;\
 	check_overwrite(oparg, sdir, cpinfo, cpdd);\
-	file_list = append_list(file_list, (void *)cpinfo);\
+	file_list = append_list((void *)cpinfo, file_list);\
 }
 
 #define TYPE_IS_DIR \
 {\
 	count_dire_plus(cpinfo, cpdd);\
 	cpinfo->copy_mode = cpinfo_tmp->copy_mode;\
-	struct stat *stat_buf = make_directory(cpinfo, oparg, cpdd);\
-	file_list = append_list(file_list, (void *)cpinfo);\
+	struct stat *stat_buf = make_directory(oparg, cpinfo, cpdd);\
+	file_list = append_list((void *)cpinfo, file_list);\
 	/* 再帰 */ \
-	file_list = dir_traverse(file_list, cpinfo, oparg, sdir, cpdd);\
-	if(cpinfo->d_para == WRITE) {ch_time_and_mod_dir(cpinfo, stat_buf, cpdd); }\
+	file_list = dir_traverse(oparg, sdir, file_list, cpinfo, cpdd);\
+	if(cpinfo->dst_para == WRITE) {ch_time_and_mod_dir(cpinfo, stat_buf, cpdd); }\
+	if(oparg->M == MOVE) { REMOVE_SOURCE_RMDIR }\
 }
 
 /*******************************************************************************
  * フォルダを走査
 *******************************************************************************/
-static VList * dir_traverse(VList *file_list, CPInfo *cpinfo_tmp, OPArg *oparg, SDir *sdir, CPDD *cpdd)
+static VList * dir_traverse(const OPArg *oparg, const SDir *sdir, VList *file_list, CPInfo *cpinfo_tmp, CPDD *cpdd)
 {
 	DIR *dp = NULL;
 	struct dirent *entry = NULL;
@@ -933,8 +969,8 @@ static inline CPInfo * cpinfo_malloc(void)
 	cpinfo->dst = NULL;
 	cpinfo->dstfs = NULL;
 	cpinfo->copy_mode = SAME;
-	cpinfo->d_para = INITIAL;
-	cpinfo->s_para = DEFAULT;
+	cpinfo->dst_para = INITIAL;
+	cpinfo->src_para = DEFAULT;
 	cpinfo->hash_check = false;
 	cpinfo->file_test = false;
 	cpinfo->src_md5 = NULL;
@@ -1133,7 +1169,7 @@ for(;;)\
 /******************************************************************************
  * ドライブが同一かどうか調べる
 *******************************************************************************/
-static inline void set_same_or_different(const VList *drive_list, const char *src, const char *dst, CPInfo *cpinfo, OPArg *oparg)
+static inline void set_same_or_different(const VList *drive_list, const char *src, const char *dst, const OPArg *oparg, CPInfo *cpinfo)
 {
 	/*
 	 * キャストしないと警告が出る
