@@ -16,11 +16,11 @@
 	print_error("unlink", __FILE__, __LINE__, cpdd);\
 	fprintf(stderr, "対象を削除出来ませんでした (%s) \n", cpinfo->dst);\
 	fprintf(stderr, "シンボリックリンクを作成できません\n");\
-	cpinfo->d_para = INITIAL;
+	cpinfo->dst_para = INITIAL;
 
 /* 関数プロトタイプ */
-static inline void create_symboliclink(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd) __attribute__((always_inline));
-static inline _Bool c_s(const OPArg *oparg, const CPInfo *cpinfo, CPDD *cpdd) __attribute__((always_inline));
+static inline void create_symboliclink(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd);
+static inline _Bool c_s(const OPArg *oparg, const CPInfo *cpinfo, CPDD *cpdd);
 /*******************************************************************************
 シンボリックリンクを作成
 *******************************************************************************/
@@ -136,7 +136,7 @@ static inline void create_symboliclink(const OPArg *oparg, CPInfo *cpinfo, CPDD
 
 	if(check == true)
 	{
-		cpinfo->d_para = WRITE;
+		cpinfo->dst_para = WRITE;
 	}
 }
 
