@@ -57,11 +57,11 @@ SDir * get_settings_dir(void)
 		char *tmp = g_build_path(G_DIR_SEPARATOR_S, sdir->user_settings_dir, "log", NULL);
 		sdir->log_dir = tmp; /* ~/.config/snowcp/log */
 
-		tmp = g_build_path(G_DIR_SEPARATOR_S, sdir->log_dir, "compare_error", NULL);
-		sdir->hash_check_error_dir = tmp; /* ~/.config/snowcp/log/compare_error */
+		tmp = g_build_path(G_DIR_SEPARATOR_S, sdir->log_dir, "hash_check_error", NULL);
+		sdir->hash_check_error_dir = tmp; /* ~/.config/snowcp/log/hash_check_error */
 
-		tmp = g_build_path(G_DIR_SEPARATOR_S, sdir->log_dir, "compare_success", NULL);
-		sdir->hash_check_success_dir = tmp; /* ~/.config/snowcp/log/compare_success */
+		tmp = g_build_path(G_DIR_SEPARATOR_S, sdir->log_dir, "hash_check_success", NULL);
+		sdir->hash_check_success_dir = tmp; /* ~/.config/snowcp/log/hash_check_success */
 	}
 
 	return sdir;
