@@ -8,7 +8,7 @@
 
 #include <errno.h>
 
-static inline void print_error(const char *func, const char *file, const int line, CPDD *cpdd) __attribute__((always_inline));
+static inline void print_error(const char *func, const char *file, const int line, CPDD *cpdd);
 
 /*******************************************************************************
 *******************************************************************************/
