@@ -13,7 +13,7 @@
 #define INPUT_LEN 256
 #define DEFAULT_BUFFER 32 * 1024 * 1024
 
-#define HASH_CHECK_MODE_SET \
+#define SET_HASH_CHECK_MODE \
 {\
 	if(buf[2] == '1')\
 	{\
@@ -145,7 +145,7 @@ OPArg * read_conf(const SDir *sdir)
 					/* ベリファイ（MD5） */
 					case 'r':
 						oparg->CHECK = V_FIVE;
-						HASH_CHECK_MODE_SET
+						SET_HASH_CHECK_MODE
 						break;
 					/* スレッドモード */
 					case 't':
