@@ -102,12 +102,12 @@ char *write_now;
 
 /* 関数プロトタイプ */
 void read_write(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd);
-inline static void mw_small(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state, md5_byte_t digest[16], struct verify_data *thread_argument, pthread_t *t_verify);
-inline static void mw_small_direct(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state, md5_byte_t digest[16], struct verify_data *thread_argument, pthread_t *t_verify);
-inline static void mw_big(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state, md5_byte_t digest[16], struct verify_data *thread_argument, pthread_t *t_verify);
-inline static void mw_big_direct(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state, md5_byte_t digest[16], struct verify_data *thread_argument, pthread_t *t_verify);
-inline static void mw_thread(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state, md5_byte_t digest[16], struct verify_data *thread_argument, pthread_t *t_verify);
-inline static void mw_thread_direct(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state, md5_byte_t digest[16], struct verify_data *thread_argument, pthread_t *t_verify);
+static inline void mw_small(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state, md5_byte_t digest[16], struct verify_data *thread_argument, pthread_t *t_verify);
+static inline void mw_small_direct(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state, md5_byte_t digest[16], struct verify_data *thread_argument, pthread_t *t_verify);
+static inline void mw_big(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state, md5_byte_t digest[16], struct verify_data *thread_argument, pthread_t *t_verify);
+static inline void mw_big_direct(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state, md5_byte_t digest[16], struct verify_data *thread_argument, pthread_t *t_verify);
+static inline void mw_thread(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state, md5_byte_t digest[16], struct verify_data *thread_argument, pthread_t *t_verify);
+static inline void mw_thread_direct(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state, md5_byte_t digest[16], struct verify_data *thread_argument, pthread_t *t_verify);
 static void * read_thread_func(void *unknown);
 static void * do_md5_append(void *tmp);
 
@@ -303,7 +303,7 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
 					}
 					else
 					{
-						cpinfo->d_para = SKIP;
+						cpinfo->dst_para = SKIP;
 					}
 				}
 				else
@@ -314,7 +314,7 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
 					}
 					else
 					{
-						cpinfo->d_para = SKIP;
+						cpinfo->dst_para = SKIP;
 					}
 				}
 			}
@@ -511,17 +511,17 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
 
 	if((open_src == true) && (open_dst == true) && (src_size_local <= total_write_local))
 	{
-		cpinfo->d_para = WRITE;
+		cpinfo->dst_para = WRITE;
 	}
 	else
 	{
-		cpinfo->d_para = INITIAL;
+		cpinfo->dst_para = INITIAL;
 	}
 }
 
 /*******************************************************************************
 *******************************************************************************/
-inline static void mw_small(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state, md5_byte_t digest[16], struct verify_data *thread_argument, pthread_t *t_verify)
+static inline void mw_small(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state, md5_byte_t digest[16], struct verify_data *thread_argument, pthread_t *t_verify)
 {
 	errno = 0;
 	buf[0] = mmap(NULL, src_size_local, PROT_READ, MAP_PRIVATE, isrc, 0);
@@ -581,7 +581,7 @@ inline static void mw_small(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state, md5_
 
 /*******************************************************************************
 *******************************************************************************/
-inline static void mw_small_direct(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state, md5_byte_t digest[16], struct verify_data *thread_argument, pthread_t *t_verify)
+static inline void mw_small_direct(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state, md5_byte_t digest[16], struct verify_data *thread_argument, pthread_t *t_verify)
 {
 	off_t read_size;
 	off_t write_size;
@@ -684,7 +684,7 @@ inline static void mw_small_direct(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *stat
 
 /*******************************************************************************
 *******************************************************************************/
-inline static void mw_big(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state, md5_byte_t digest[16], struct verify_data *thread_argument, pthread_t *t_verify)
+static inline void mw_big(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state, md5_byte_t digest[16], struct verify_data *thread_argument, pthread_t *t_verify)
 {
 	for(;;)
 	{
@@ -780,7 +780,7 @@ LOOP_END:
 
 /*******************************************************************************
 *******************************************************************************/
-inline static void mw_big_direct(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state, md5_byte_t digest[16], struct verify_data *thread_argument, pthread_t *t_verify)
+static inline void mw_big_direct(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state, md5_byte_t digest[16], struct verify_data *thread_argument, pthread_t *t_verify)
 {
 	off_t read_size;
 	off_t write_size;
@@ -930,7 +930,7 @@ cpdd->thread_mode_count++;\
 
 /*******************************************************************************
 *******************************************************************************/
-inline static void mw_thread(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state, md5_byte_t digest[16], struct verify_data *thread_argument, pthread_t *t_verify)
+static inline void mw_thread(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state, md5_byte_t digest[16], struct verify_data *thread_argument, pthread_t *t_verify)
 {
 	GET_BUFFER_SIZE
 
@@ -1015,7 +1015,7 @@ inline static void mw_thread(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd, md5
 
 /*******************************************************************************
 *******************************************************************************/
-inline static void mw_thread_direct(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state, md5_byte_t digest[16], struct verify_data *thread_argument, pthread_t *t_verify)
+static inline void mw_thread_direct(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state, md5_byte_t digest[16], struct verify_data *thread_argument, pthread_t *t_verify)
 {
 	GET_BUFFER_SIZE
 
