@@ -1,11 +1,12 @@
 #include "analyze_argument.h"
 #include "check_target.h"
-#include "do_compare_verify_two.h"	// inline
+#include "compare_verify_two.h"	// inline
 #include "get_drive_list.h"
 #include "get_settings_dir.h"
 #include "help.h"
 #include "print_error.h"	// inline
 #include "read_conf.h"
+#include "remove_source_rmdir.h"
 #include "set_signal.h"
 #include "struct_CPDD.h"
 #include "struct_DPath.h"
@@ -20,7 +21,7 @@
 #include <unistd.h>
 
 /* 関数プロトタイプ */
-static inline void delete_src(const OPArg *oparg, const VList *file_list, CPDD *cpdd) __attribute__((always_inline));
+static inline void delete_src(const VList *file_list, CPDD *cpdd);
 
 /*******************************************************************************
 *******************************************************************************/
@@ -88,29 +89,14 @@ int main(int argc, char **argv)
 		puts("ハッシュ値のチェックを開始します...");
 		fflush(stdout);
 
-		do_compare_verify_two(oparg, file_list, sdir, cpdd);
+		compare_verify_two(oparg, file_list, sdir, cpdd);
 
 		puts("ハッシュ値のチェックを完了しました...");
 		fflush(stdout);
 	}
 
-	if(oparg->M == MOVE)
-	{
-		if(
-			((oparg->CHECK == NOT) && ((cpdd->mk_file_count > 0) || (cpdd->mk_link_count > 0) || (cpdd->dir_count > 0)))
-			||
-			((oparg->CHECK != NOT) && ((cpdd->mk_link_count > 0) || (cpdd->dir_count > 0)))
-		)
-		{
-			puts("コピー元の削除を開始します...");
-			fflush(stdout);
-
-			delete_src(oparg, file_list, cpdd);
-
-			puts("コピー元の削除を完了しました...");
-			fflush(stdout);
-		}
-	}
+	/* ファイルとリンクはコピー直後に削除しているので、チェックするのはフォルダだけでよい。 */
+	if((oparg->M == MOVE) && (cpdd->dir_count > 0)) { delete_src(file_list, cpdd); }
 
 	puts("");
 
@@ -147,7 +133,7 @@ int main(int argc, char **argv)
 
 /*******************************************************************************
 *******************************************************************************/
-static inline void delete_src(const OPArg *oparg, const VList *file_list, CPDD *cpdd)
+static inline void delete_src(const VList *file_list, CPDD *cpdd)
 {
 	/*
 	 * キャストしないと警告が出る
@@ -162,44 +148,14 @@ static inline void delete_src(const OPArg *oparg, const VList *file_list, CPDD *
 
 		switch(cpinfo->src_type)
 		{
-		case REGULAR:
-			if(oparg->CHECK == NOT)
-			{
-				if((cpinfo->d_para == WRITE) && (cpinfo->src_size <= cpinfo->dst_size))
-				{
-					SOURCE_UNLINK
-				}
-			}
-			else
-			{
-				if((cpinfo->hash_check == true) && (cpinfo->d_para == WRITE) && (cpinfo->s_para != UNLINK) && (cpinfo->src_size <= cpinfo->dst_size))
-				{
-					SOURCE_UNLINK
-				}
-				else if((cpinfo->d_para == WRITE) && (cpinfo->s_para != UNLINK) && (cpinfo->src_size == 0) && (cpinfo->dst_size == 0))
-				{
-					SOURCE_UNLINK
-				}
-			}
+		case DIRECTORY:
+			REMOVE_SOURCE_RMDIR
 			break;
 
 		case SYMBOLICLINK:
-			if(cpinfo->d_para == WRITE)
-			{
-				SOURCE_UNLINK
-			}
 			break;
 
-		case DIRECTORY:
-			errno = 0;
-			if(rmdir(cpinfo->src) == -1)
-			{
-				if((errno != ENOTEMPTY) && (errno != ENOENT))
-				{
-					print_error("remove", __FILE__, __LINE__, cpdd);
-					fprintf(stderr, "`%s' の削除に失敗しました\n", cpinfo->src);
-				}
-			}
+		case REGULAR:
 			break;
 
 		default:
