@@ -27,8 +27,8 @@ typedef enum dst_parameter
 
 typedef enum src_parameter
 {
-	/* 同じ名前は使えないのでDELETEではなくUNLINKにした */
-	UNLINK,
+	/* 同じ名前は使えないのでDELETEではなくREMOVEにした */
+	REMOVE,
 
 	/* 同じ名前は使えないのでINITIALではなくDEFAULTにした */
 	DEFAULT,
@@ -41,8 +41,8 @@ typedef struct copy_infomation
 	char *dstfs;
 	CFT src_type;
 	CMF copy_mode;
-	DPT d_para;
-	SPT s_para;
+	DPT dst_para;
+	SPT src_para;
 	_Bool hash_check;
 	_Bool file_test;
 	char *src_md5;
