@@ -38,7 +38,7 @@ static _Bool read_finish;
 #define UNLINK_MISS_FILE \
 	print_error("NODATA", __FILE__, __LINE__, cpdd);\
 	write_log_hash_check(cpinfo, cpinfo->src_md5, hex_output, sdir, cpdd, false);\
-	cpinfo->d_para = DELETE;\
+	cpinfo->dst_para = DELETE;\
 \
 	errno = 0;\
 	if(unlink(cpinfo->dst) == -1)\
@@ -224,7 +224,7 @@ static void o_direct(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD
 		fprintf(stderr, "メモリの確保に失敗しました\n");
 		print_error("NODATA", __FILE__, __LINE__, cpdd);
 		write_log_hash_check(cpinfo, cpinfo->src_md5, "NULL", sdir, cpdd, false);
-		cpinfo->d_para = INITIAL;
+		cpinfo->dst_para = INITIAL;
 		break;
 	}
 }
