@@ -130,7 +130,7 @@ void verify_md5sum(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *c
 				fprintf(stderr, "`%s' を削除します\n", cpinfo->dst);
 				print_error("NODATA", __FILE__, __LINE__, cpdd);
 				write_log_hash_check(cpinfo, cpinfo->src_md5, ddst, sdir, cpdd, false);
-				cpinfo->d_para = DELETE;
+				cpinfo->dst_para = DELETE;
 
 				errno = 0;
 				if(unlink(cpinfo->dst) == -1)
