@@ -13,9 +13,9 @@
 #include <sys/stat.h>
 
 /* 関数プロトタイプ */
-static inline void write_log_hash_check(const CPInfo *cpinfo, const char *src_hash, const char *dst_hash, const SDir *sdir, CPDD *cpdd, _Bool c_success) __attribute__((always_inline));
-static inline void set_today(char *today) __attribute__((always_inline));
-static inline void set_time_now(char *hms) __attribute__((always_inline));
+static inline void write_log_hash_check(const CPInfo *cpinfo, const char *src_hash, const char *dst_hash, const SDir *sdir, CPDD *cpdd, _Bool c_success);
+static inline void set_today(char *today);
+static inline void set_time_now(char *hms);
 
 static inline void write_log_hash_check(const CPInfo *cpinfo, const char *src_hash, const char *dst_hash, const SDir *sdir, CPDD *cpdd, _Bool c_success)
 {
